@@ -16,13 +16,12 @@ use std::env;
 use std::fs;
 
 // To generate:
-// parol -f .\examples\list\list.par -e .\examples\list\list-exp.par -p .\examples\list\list_parser.rs -a .\examples\list\list_grammar_trait.rs -t ListGrammar -m list_grammar
+// parol -f ./examples/list/list.par -e ./examples/list/list-exp.par -p ./examples/list/list_parser.rs -a ./examples/list/list_grammar_trait.rs -t ListGrammar -m list_grammar
 
 // To run the example
-// cargo run --example list -- .\examples\list\list_test.txt
+// cargo run --example list -- ./examples/list/list_test.txt
 
 fn main() -> Result<()> {
-    // $env:RUST_LOG="main=off,parol_runtime=trace,list=debug"
     env_logger::init();
     debug!("env logger started");
 
@@ -33,7 +32,7 @@ fn main() -> Result<()> {
             .into_diagnostic()
             .wrap_err(format!("Can't read file {}", file_name))?;
         let mut list_grammar = ListGrammar::new();
-        let syntax_tree = parse(&input, file_name.to_owned(), &mut list_grammar)
+        let syntax_tree = parse(&input, &file_name, &mut list_grammar)
             .wrap_err(format!("Failed parsing file {}", file_name))?;
         println!("{}", list_grammar);
         generate_tree_layout(&syntax_tree, &file_name).wrap_err("Error generating tree layout")
