@@ -17,6 +17,6 @@ pub fn main(args: &Args) -> Result<()> {
     let file_name = &args.grammar_file;
 
     let grammar_config = obtain_grammar_config(&file_name, false)?;
-    println!("{}", render_par_string(&grammar_config, true));
+    println!("{}", render_par_string(&grammar_config, true)?);
     Ok(())
 }
