@@ -2,6 +2,7 @@
 //! The module contains the conversion to a the PAR format.
 //!
 use crate::{GrammarConfig, ScannerConfig, StrVec};
+use miette::Result;
 use std::fmt::Debug;
 
 #[derive(BartDisplay, Debug, Default)]
@@ -32,17 +33,21 @@ struct ScannerConfigElements {
 ///
 /// Formats the given GrammarConfig in the PAR format.
 ///
-pub fn render_par_string(grammar_config: &GrammarConfig, add_index_comment: bool) -> String {
-    let title = format!(
-        "\n%title \"{}\"",
-        grammar_config.title.clone().unwrap_or_default()
-    );
+pub fn render_par_string(
+    grammar_config: &GrammarConfig,
+    add_index_comment: bool,
+) -> Result<String> {
+    let title = grammar_config
+        .title
+        .as_ref()
+        .map_or("".to_owned(), |title| format!("\n%title \"{}\"", title));
 
-    let comment = if let Some(comment) = grammar_config.comment.as_ref() {
-        format!("\n%comment \"{}\"", comment)
-    } else {
-        "".to_owned()
-    };
+    let comment = grammar_config
+        .comment
+        .as_ref()
+        .map_or("".to_owned(), |comment| {
+            format!("\n%comment \"{}\"", comment)
+        });
 
     let line_comments = grammar_config.scanner_configurations[0]
         .line_comments
@@ -70,22 +75,21 @@ pub fn render_par_string(grammar_config: &GrammarConfig, add_index_comment: bool
         "\n%auto_ws_off".to_owned()
     };
 
-    let scanner_state_resolver = |s: &[usize]| {
-        s.iter()
-            .map(|s| {
-                grammar_config.scanner_configurations[*s]
-                    .scanner_name
-                    .clone()
-            })
-            .collect::<Vec<String>>()
-            .join(", ")
-    };
+    let scanner_state_resolver = grammar_config.get_scanner_state_resolver();
 
-    let mut productions = Vec::new();
-
-    grammar_config.cfg.pr.iter().for_each(|p| {
-        productions.push(p.format(&scanner_state_resolver));
-    });
+    let mut productions =
+        grammar_config
+            .cfg
+            .pr
+            .iter()
+            .fold(Ok(Vec::new()), |acc: Result<Vec<String>>, p| {
+                if let Ok(mut acc) = acc {
+                    acc.push(p.format(&scanner_state_resolver)?);
+                    Ok(acc)
+                } else {
+                    acc
+                }
+            })?;
 
     if add_index_comment {
         let width = (productions.len() as f32).log10() as usize + 1;
@@ -127,7 +131,7 @@ pub fn render_par_string(grammar_config: &GrammarConfig, add_index_comment: bool
         scanner_states,
         productions,
     };
-    format!("{}", elements)
+    Ok(format!("{}", elements))
 }
 
 fn render_scanner_config_string(scanner_config: &ScannerConfig) -> String {
@@ -210,7 +214,7 @@ mod test {
             .with_comment(comment)
             .add_scanner(ScannerConfig::default());
 
-        let par_str = render_par_string(&grammar_config, true);
+        let par_str = render_par_string(&grammar_config, true).unwrap();
         let par_str = par_str.replace("\r\n", "\n");
         let expected = r#"%start S
 %title "Test grammar"
