@@ -33,6 +33,7 @@ pub struct UserTraitGenerator<'a> {
 impl<'a> UserTraitGenerator<'a> {
     fn generate_inner_action_args(&self, action: &Action) -> String {
         // We reference the parse_tree argument only if a token is in the argument list
+        let lifetime = if self.auto_generate { "<'t>" } else { "" };
         let mut parse_tree_argument_used = false;
         let mut arguments = action
             .args
@@ -41,12 +42,13 @@ impl<'a> UserTraitGenerator<'a> {
                 if matches!(a.arg_type, ASTType::Token(_)) {
                     parse_tree_argument_used = true;
                 }
-                format!("{}: &ParseTreeStackEntry", a.name(),)
+                format!("{}: &ParseTreeStackEntry{}", a.name(), lifetime)
             })
             .collect::<Vec<String>>();
         arguments.push(format!(
-            "{}parse_tree: &Tree<ParseTreeType>",
-            NmHlp::item_unused_indicator(self.auto_generate && parse_tree_argument_used)
+            "{}parse_tree: &Tree<ParseTreeType{}>",
+            NmHlp::item_unused_indicator(self.auto_generate && parse_tree_argument_used),
+            lifetime
         ));
         arguments.join(", ")
     }
@@ -67,7 +69,7 @@ impl<'a> UserTraitGenerator<'a> {
                 .for_each(|arg| {
                     let arg_name = arg.name();
                     code.push(format!(
-                        "let {} = {}.token(parse_tree)?.to_owned();",
+                        "let {} = *{}.token(parse_tree)?;",
                         arg_name, arg_name
                     ))
                 });
@@ -105,7 +107,7 @@ impl<'a> UserTraitGenerator<'a> {
         if self.auto_generate && action.sem == ProductionAttribute::AddToCollection {
             code.push("// Add an element to the vector".to_string());
             code.push(format!(
-                " {}.push({});",
+                " {}.push({}_built);",
                 action.args.iter().last().unwrap().name,
                 &action.fn_name,
             ));
@@ -115,10 +117,10 @@ impl<'a> UserTraitGenerator<'a> {
     fn generate_result_builder(&self, code: &mut StrVec, action: &Action) {
         if self.auto_generate {
             if action.sem == ProductionAttribute::CollectionStart {
-                code.push(format!("let {} = Vec::new();", action.fn_name));
+                code.push(format!("let {}_built = Vec::new();", action.fn_name));
             } else if action.sem == ProductionAttribute::AddToCollection {
                 code.push(format!(
-                    "let {} = {}Builder::default()",
+                    "let {}_built = {}Builder::default()",
                     action.fn_name,
                     NmHlp::to_upper_camel_case(&action.non_terminal)
                 ));
@@ -142,7 +144,7 @@ impl<'a> UserTraitGenerator<'a> {
                     &action.fn_name
                 };
                 code.push(format!(
-                    "let {} = {}Builder::default()",
+                    "let {}_built = {}Builder::default()",
                     action.fn_name,
                     NmHlp::to_upper_camel_case(builder_prefix)
                 ));
@@ -161,7 +163,7 @@ impl<'a> UserTraitGenerator<'a> {
                     // Type adjustment to the non-terminal enum
                     // let list_0 = List::List0(list_0);
                     code.push(format!(
-                        "let {} = {}::{}({});",
+                        "let {}_built = {}::{}({}_built);",
                         action.fn_name,
                         NmHlp::to_upper_camel_case(&action.non_terminal),
                         NmHlp::to_upper_camel_case(builder_prefix),
@@ -178,8 +180,8 @@ impl<'a> UserTraitGenerator<'a> {
         action: &Action,
         parol_grammar: &'a ParolGrammar,
     ) {
-        if self.auto_generate {
-            if parol_grammar
+        if self.auto_generate
+            && parol_grammar
                 .item_stack
                 .iter()
                 .filter_map(|item| match item {
@@ -187,15 +189,13 @@ impl<'a> UserTraitGenerator<'a> {
                     _ => None,
                 })
                 .any(|lhs| &action.non_terminal == lhs)
-            {
-                code.push("// Calling user action here".to_string());
-                // self.user_grammar.num(num_4.clone())?;
-                code.push(format!(
-                    "self.user_grammar.{}({}.clone())?;",
-                    NmHlp::to_lower_snake_case(&action.non_terminal),
-                    action.fn_name
-                ));
-            }
+        {
+            code.push("// Calling user action here".to_string());
+            code.push(format!(
+                "self.user_grammar.{}(&{}_built)?;",
+                NmHlp::to_lower_snake_case(&action.non_terminal),
+                action.fn_name
+            ));
         }
     }
 
@@ -213,7 +213,7 @@ impl<'a> UserTraitGenerator<'a> {
                 // The output type of the action is the type generated for the action's non-terminal
                 // filled with type kind of the action
                 code.push(format!(
-                    "self.push(ASTType::{}({}), context);",
+                    "self.push(ASTType::{}({}_built), context);",
                     NmHlp::to_upper_camel_case(&action.non_terminal),
                     action.fn_name
                 ));
@@ -222,7 +222,7 @@ impl<'a> UserTraitGenerator<'a> {
     }
 
     fn generate_user_action_args(non_terminal: &str) -> String {
-        format!("_arg: {}", NmHlp::to_upper_camel_case(non_terminal))
+        format!("_arg: &{}<'t>", NmHlp::to_upper_camel_case(non_terminal))
     }
 
     fn generate_caller_argument_list(pr: &Pr) -> String {
@@ -254,6 +254,7 @@ impl<'a> UserTraitGenerator<'a> {
                 let struct_data = NonTerminalTypeStruct {
                     comment,
                     non_terminal,
+                    lifetime: ast_type.lifetime(),
                     members: m.iter().fold(StrVec::new(4), |mut acc, (n, t)| {
                         acc.push(format!("{}: {},", n, t));
                         acc
@@ -265,11 +266,12 @@ impl<'a> UserTraitGenerator<'a> {
                 let struct_data = NonTerminalTypeEnum {
                     comment,
                     non_terminal: n.to_string(),
+                    lifetime: ast_type.lifetime(),
                     members: m.iter().fold(StrVec::new(4), |mut acc, (c, t)| {
                         acc.push(NmHlp::to_upper_camel_case(&format!(
                             "{}({}),",
                             c,
-                            t.type_name()
+                            t.type_name(),
                         )));
                         acc
                     }),
@@ -280,6 +282,7 @@ impl<'a> UserTraitGenerator<'a> {
                 let struct_data = NonTerminalTypeVec {
                     comment,
                     non_terminal,
+                    lifetime: ast_type.lifetime(),
                     type_ref: r.clone(),
                 };
                 Some(format!("{}", struct_data))
@@ -288,6 +291,7 @@ impl<'a> UserTraitGenerator<'a> {
                 let struct_data = NonTerminalTypeStruct {
                     comment,
                     non_terminal,
+                    lifetime: ast_type.lifetime(),
                     members: StrVec::new(0),
                 };
                 Some(format!("{}", struct_data))
@@ -369,7 +373,7 @@ impl<'a> UserTraitGenerator<'a> {
                     self.generate_stack_pops(&mut code, a)?;
                     self.generate_result_builder(&mut code, a);
                     self.generate_push_semantic(&mut code, a);
-                    self.generate_user_action_call(&mut code, a, &self.parol_grammar);
+                    self.generate_user_action_call(&mut code, a, self.parol_grammar);
                     self.generate_stack_push(&mut code, a);
                     let user_trait_function_data = UserTraitFunctionDataBuilder::default()
                         .fn_name(fn_name)
